download_sqlite_db: Download the Pediatric Drug Safety database
Description
Download the database published in Giangreco et al. 2022. This function will prompt to download the database, so the cache directory will be identified and the database will be downloaded to it only after consent. Warning, the size of the uncompressed 'sqlite' file is close to 0.9GB or 900 MB. Use with caution.
The method to download the sqlite database. See download.file
quiet
Whether to download quietly. See download.file
timeout
Extended download session for downloading this file. Default is 1000 seconds.
force
Whether to force the download of the database. Defaults to FALSE. Needs to be TRUE for database to download. The function will prompt for confirmation.